@@ -46,9 +46,10 @@ where
             pending = replace(&mut lock.ops, Vec::new());
             running = lock.running;
         }
-        operation()?;
-        release_all(&pending)?;
-        if !running {
+        if running {
+            operation()?;
+            release_all(&pending)?;
+        } else {
             break Ok(());
         }
     }
@@ -84,16 +85,15 @@ impl<T: 'static + Send> BackgroundOps<T> {
         Ok(())
     }
 }
-
-impl<T> Drop for BackgroundOps<T> {
-    fn drop(&mut self) {
-        let (ops, cond) = &*self.pending;
-        {
-            let mut pend = ops.lock().unwrap();
-            pend.terminate();
-            cond.notify_one();
-        }
-        if let Some(handle) = replace(&mut self.flush_thread, None) {
+impl<T> BackgroundOps<T> {
+    pub fn finish(&mut self) {
+        if let Some(handle) = self.flush_thread.take() {
+            let (ops, cond) = &*self.pending;
+            {
+                let mut pend = ops.lock().unwrap();
+                pend.terminate();
+                cond.notify_one();
+            }
             handle.join().unwrap();
         }
     }
@@ -131,7 +131,7 @@ mod tests {
         sleep(Duration::from_millis(1));
         bg.add_pending(2).unwrap();
         bg.add_pending(3).unwrap();
-        sleep(Duration::from_millis(31));
+        sleep(Duration::from_millis(61));
         assert_eq!(counter.load(Ordering::SeqCst), 3);
     }
 }
