@@ -55,7 +55,7 @@
 mod address;
 mod allocator;
 mod config;
-mod discref;
+mod device;
 mod error;
 mod flush_checksum;
 mod id;
@@ -284,7 +284,7 @@ impl Persy {
 
     /// Begin a new transaction.
     ///
-    /// The transaction isolation level is 'read_commited'.
+    /// The transaction isolation level is 'read_committed'.
     /// for commit call [`prepare`] and [`commit`]
     ///
     /// [`prepare`]:struct.Transaction.html#method.prepare
@@ -308,7 +308,7 @@ impl Persy {
 
     /// Begin a new transaction specifying parameters for the transaction.
     ///
-    /// The transaction isolation level is 'read_commited'.
+    /// The transaction isolation level is 'read_committed'.
     /// for commit call [`prepare`] and [`commit`]
     ///
     /// [`prepare`]:struct.Transaction.html#method.prepare
