@@ -146,6 +146,9 @@ impl Segment {
         }
         Ok(pages)
     }
+    pub fn set_last_page(&mut self, page: u64) {
+        self.last_page = page;
+    }
 }
 
 pub(crate) trait SegmentPageRead: PageOps {
@@ -407,6 +410,12 @@ impl Segments {
         }
     }
 
+    pub fn set_segment_last_page(&mut self, id: SegmentId, page: u64) {
+        if let Some(s) = self.segments.get_mut(&id) {
+            s.set_last_page(page);
+        }
+    }
+
     pub fn segment_by_id(&self, id: SegmentId) -> Option<&Segment> {
         self.segments.get(&id)
     }
